searchData={"items":[{"type":"module","title":"PairingHeap","doc":"Elixir implementation of a\n[_pairing heap_](https://en.wikipedia.org/wiki/Pairing_heap).","ref":"PairingHeap.html"},{"type":"module","title":"Background - PairingHeap","doc":"A heap is a tree data structure that ensures that the root always has the \nminimum or maximum key value, depending on the desired sort order. The heap was \nfirst introduced in the context of efficient sorting \n(see [_heapsort_](https://en.wikipedia.org/wiki/Heapsort)), but it can also be \nused to implement a \n[priority queue](https://en.wikipedia.org/wiki/Priority_queue).  \n\nEach node of a heap has a _key_ on which the data is ordered, as well as a\ncollection of child nodes. Every heap node satisfies the _heap property_\nthat the node key is either less than or equal to \n(a _min-heap_) or greater than or equal to (a _max-heap_) the keys of its\nchildren. In a min-heap, the root node has the smallest key in the tree, while \nfor a max-heap, the root key is the largest.\n\nA pairing heap is one of a handful of commonly-used heap data structures. It\nhas excellent performance characteristics, with `O(1)` time complexity for an\ninsert and for viewing the root node, and `O(log n)` amortized time complexity \nfor removing the root node and rebuilding the heap. The algorithms for \nmaintaining a pairing heap have especially simple implementations in a\nfunctional language, which is one reason for doing this in Elixir.","ref":"PairingHeap.html#module-background"},{"type":"module","title":"Usage - PairingHeap","doc":"`PairingHeap` provides operations for the creation of a heap, for insertion, \nretrieval, and deletion of elements, and for merging multiple heaps.\n\nTo create an empty min-heap that compares keys with `&<=/2`, use \n`PairingHeap.new/1`:\n\n```elixir\niex> PairingHeap.new(:min)\n#PairingHeap \n```\n\nAn empty heap is indicated with `root: :empty`.\n\n> The `PairingHeap` struct is not intended to be used directly. Use the \n> public API when working with an instance of `PairingHeap`.\n\nThe data contained in each node of a heap is a key-value pair expressed as the \ntuple `{key, value}`. A `key` is what is being ordered in the heap, while the \n`value` can be data of any type. Note that a heap is a not a set; duplicate \nkeys, values, and key-value pairs can be present.\n\nMultiple key-value pairs can be added to a heap at the time of creation with \n`PairingHeap.new/2`:\n\n```elixir\niex> PairingHeap.new(:min, [{2, :b}, {1, :a}])\n#PairingHeap \n```\n\nThe first argument to `PairingHeap.new/1` and `PairingHeap.new/2` is the `mode`\nof the heap, which can be one of\n\n  * `:min` - a min-heap, where keys are compared with `&<=/2`\n  * `:max` - a max-heap, where keys are compared with `&>=/2`\n  * `{:min | :max, module}` - a min- or max-heap, where the `module` must\n      implement a `compare` function with signature `(any, any -> :lt | :eq | :gt)`\n\nFor example, a min-heap with `Date` keys would be initialized as\n\n```elixir\niex> PairingHeap.new({:min, Date}, [{~D[2023-09-01], :b}, {~D[2023-08-01], :a}])\n#PairingHeap \n```\n\nTo add a single key-value pair to a heap, use `PairingHeap.put/3`:\n\n```eliixr\niex> PairingHeap.new(:min) |> PairingHeap.put(1, :a)\n#PairingHeap \n```\n\n`PairingHeap.peek/1` is used to obtained the key-value pair of the root without\nmodifying the heap:\n\n```elixir\niex> PairingHeap.new(:min, [{1, :a}]) |> PairingHeap.peek()\n{:ok, {1, :a}}\n```\n\nExtraction and removal of the root node is accomplished with `PairingHeap.pop/1`:\n\n```elixir\niex> {:ok, {key, value}, heap} = \n...>   PairingHeap.new(:min, [{1, :a}]) \n...>   |> PairingHeap.pop()\niex> {key, value}\n{1, :a}\niex> heap\n#PairingHeap \n```\n\nBoth `PairingHeap.peek/1` and `PairingHeap.pop/1` return `:error` if the\nheap is empty.\n\n`PairingHeap.pull/2` pops zero or more key-value pairs from the heap and returns \nthe updated heap:\n\n```elixir\niex> {pairs, heap} =\n...>   PairingHeap.new(:min, [{3, :c}, {1, :a}, {2, :b}])\n...>   |> PairingHeap.pull(2)\niex> pairs\n[{1, :a}, {2, :b}]\niex> heap\n#PairingHeap \n```\n\nIf the number in `PairingHeap.pull/2` is greater than the heap size, all of the \nkey-value pairs are returned, along with an empty heap.\n\nTwo heaps with the same `mode` can be merged with `PairingHeap.merge/2`:\n\n```elixir\niex> heap1 = PairingHeap.new(:min, [{2, :b}])\niex> heap2 = PairingHeap.new(:min, [{1, :a}])\niex> PairingHeap.merge(heap1, heap2)\n#PairingHeap \n```\n\nSimilarly, one or more heaps can be merged with `PairingHeap.merge/1`, which \ntakes a list of heaps as its sole argument:\n\n```elixir\niex> heap1 = PairingHeap.new(:min, [{2, :b}])\niex> heap2 = PairingHeap.new(:min, [{1, :a}])\niex> PairingHeap.merge([heap1, heap2])\n#PairingHeap \n```\n\nTo quickly dump the key-values pairs in the heap without guarantees on the\nordering, use `PairingHeap.dump/1`:\n\n```elixir\niex> h = PairingHeap.new(:min, [{2, :b}, {1, :a}, {3, :c}])\niex> PairingHeap.dump(h)\n[{1, :a}, {3, :c}, {2, :b}]\n```\n\nThis is faster than `Enum.to_list/1` (see below).","ref":"PairingHeap.html#module-usage"},{"type":"module","title":"Enumerable and Collectable - PairingHeap","doc":"`PairingHeap` implements the `Enumerable` and `Collectable` protocols, meaning\nthat functions from `Enum` and `Stream` are available. \n\n`Enum.into` is a simple way to add a batch of key-value pairs to a heap:\n\n```elixir\niex> heap = PairingHeap.new(:min, [{2, :b}])\niex> [{3, :c}, {1, :a}] |> Enum.into(heap)\n#PairingHeap \n```\n\nUse `Enum.to_list` to list the entire contents of the heap in key order:\n\n```elixir\niex> heap = PairingHeap.new(:min, [{3, :c}, {1, :a}, {2, :b}])\niex> heap |> Enum.to_list()\n[{1, :a}, {2, :b}, {3, :c}]\n```\n\n`map`, `filter`, and `reduce` are also available for `PairingHeap`. But beware:  \n\n> Any operation that pops `k` elements from a heap will have `O(k log n)`\n> complexity on average.","ref":"PairingHeap.html#module-enumerable-and-collectable"},{"type":"module","title":"Miscellaneous details - PairingHeap","doc":"- Like most other heap algorithms, a pairing heap does not produce a \n[stable sort](https://en.wikipedia.org/wiki/Sorting_algorithm#Stability). \n\n- In this implementation of a pairing heap, a new item whose key equals the key\n  of the root node will become the new root node.\n\n```elixir\niex> heap = PairingHeap.new(:min, [{2, :b}, {1, :a}])\niex> heap |> PairingHeap.put(1, :aa) |> Enum.to_list()\n[{1, :aa}, {1, :a}, {2, :b}]\n```\n\n- Emptying a `PairingHeap` with 1,000,000 randomly inserted items takes a \n  couple seconds. For `PairingHeap` sizes less than 1,000,000 the time to \n  pop an item is of order 1 microsecond.","ref":"PairingHeap.html#module-miscellaneous-details"},{"type":"function","title":"PairingHeap.dump/1","doc":"Return the list of items in the heap.\n\nWhile the head of the list will be the item in the root node of the heap,\nthere is not guarantee that the remaining items will be in key order. This\nfunciton runs in `O(n)` time and is faster than repeatedly calling `pop/1`.","ref":"PairingHeap.html#dump/1"},{"type":"function","title":"Examples - PairingHeap.dump/1","doc":"iex> heap = PairingHeap.new(:min, [{3, :c}, {1, :a}, {2, :b}])\n    iex> PairingHeap.dump(heap)\n    [{1, :a}, {2, :b}, {3, :c}]","ref":"PairingHeap.html#dump/1-examples"},{"type":"function","title":"PairingHeap.empty?/1","doc":"Return `true` if the heap is empty, and `false` otherwise.","ref":"PairingHeap.html#empty?/1"},{"type":"function","title":"Examples - PairingHeap.empty?/1","doc":"iex> PairingHeap.new(:min) |> PairingHeap.empty?()\n    true","ref":"PairingHeap.html#empty?/1-examples"},{"type":"function","title":"PairingHeap.member?/2","doc":"Retrun `true` if the `heap` contains the key-value `pair`, and `false`\notherwise.","ref":"PairingHeap.html#member?/2"},{"type":"function","title":"Examples - PairingHeap.member?/2","doc":"iex> heap = PairingHeap.new(:min, [{3, :c}, {1, :a}, {2, :b}])\n    iex> heap |> PairingHeap.member?({2, :b})\n    true","ref":"PairingHeap.html#member?/2-examples"},{"type":"function","title":"PairingHeap.merge/1","doc":"Merge a list of one or more heaps into a single heap.\n\nAn exception will be raised if the modes of the heaps are not identical.","ref":"PairingHeap.html#merge/1"},{"type":"function","title":"Examples - PairingHeap.merge/1","doc":"iex> PairingHeap.merge([\n    ...>   PairingHeap.new(:min, [{1, :a}]),\n    ...>   PairingHeap.new(:min, [{2, :b}])\n    ...> ])\n    #PairingHeap","ref":"PairingHeap.html#merge/1-examples"},{"type":"function","title":"PairingHeap.merge/2","doc":"Merge two heaps into a single heap.\n\nAn exception will be raised if the modes of the two heaps are not identical.","ref":"PairingHeap.html#merge/2"},{"type":"function","title":"Examples - PairingHeap.merge/2","doc":"iex> PairingHeap.merge(\n    ...>   PairingHeap.new(:min, [{1, :a}]),\n    ...>   PairingHeap.new(:min, [{2, :b}])\n    ...> )\n    #PairingHeap","ref":"PairingHeap.html#merge/2-examples"},{"type":"function","title":"PairingHeap.new/1","doc":"Return an empty heap with the given `mode`.\n\nThe `mode` can be one of\n\n  * `:min` - a _min-heap_, where keys are compared with `&<=/2`\n  * `:max` - a _max-heap_, where keys are compared with `&>=/2`\n  * `{:min | :max, module}` - a min or max heap, where the `module` must\n    implement a `compare` funciton with signature `(any, any -> :lt | :eq | :gt)`","ref":"PairingHeap.html#new/1"},{"type":"function","title":"Examples - PairingHeap.new/1","doc":"iex> PairingHeap.new(:min)\n    #PairingHeap","ref":"PairingHeap.html#new/1-examples"},{"type":"function","title":"PairingHeap.new/2","doc":"Return a heap with the given `mode` and insert each key-value pair in the\ngiven `list`.\n\nThe `mode` can be one of\n\n  * `:min` - a _min-heap_, where keys are compared with `&<=/2`\n  * `:max` - a _max-heap_, where keys are compared with `&>=/2`\n  * `{:min | :max, module}` - a min or max heap, where the `module` must\n    implement a `compare` funciton with signature `(any, any -> :lt | :eq | :gt)`","ref":"PairingHeap.html#new/2"},{"type":"function","title":"Examples - PairingHeap.new/2","doc":"iex> PairingHeap.new(:min, [{2, :b}, {1, :a}])\n    #PairingHeap","ref":"PairingHeap.html#new/2-examples"},{"type":"function","title":"PairingHeap.peek/1","doc":"Return the root key-value pair in the heap without modifying the heap.\n\nIf the heap is non-empty, this returns `{:ok, {key, value}}`. If the heap is empty,\n`:error` is returned.","ref":"PairingHeap.html#peek/1"},{"type":"function","title":"Examples - PairingHeap.peek/1","doc":"iex> PairingHeap.new(:min, [{1, :a}]) |> PairingHeap.peek()\n    {:ok, {1, :a}}","ref":"PairingHeap.html#peek/1-examples"},{"type":"function","title":"PairingHeap.pop/1","doc":"Return the root key-value pair in the heap, as well as the updated heap after\nthe root is removed.\n\nIf the heap is non-empty, this returns `{:ok, {key, value}, heap}`. If the heap\nis empty, `:error` is returned.","ref":"PairingHeap.html#pop/1"},{"type":"function","title":"Examples - PairingHeap.pop/1","doc":"iex> {:ok, {key, value}, heap} =\n    ...>   PairingHeap.new(:min, [{1, :a}])\n    ...>   |> PairingHeap.pop()\n    iex> {key, value}\n    {1, :a}\n    iex> heap\n    #PairingHeap","ref":"PairingHeap.html#pop/1-examples"},{"type":"function","title":"PairingHeap.pull/2","doc":"Return the first `n` key-value pairs from the heap and the final state of the heap.\n\nIf the heap `size` is less than `n`, all key-value pairs are returned along with\nan empty heap.","ref":"PairingHeap.html#pull/2"},{"type":"function","title":"Examples - PairingHeap.pull/2","doc":"iex> {pairs, heap} =\n    ...>   PairingHeap.new(:min, [{3, :c}, {1, :a}, {2, :b}])\n    ...>   |> PairingHeap.pull(2)\n    iex> pairs\n    [{1, :a}, {2, :b}]\n    iex> heap\n    #PairingHeap","ref":"PairingHeap.html#pull/2-examples"},{"type":"function","title":"PairingHeap.put/3","doc":"Insert a new key and value to the heap and return the updated heap.","ref":"PairingHeap.html#put/3"},{"type":"function","title":"Examples - PairingHeap.put/3","doc":"iex> PairingHeap.new(:min) |> PairingHeap.put(1, :a)\n    #PairingHeap","ref":"PairingHeap.html#put/3-examples"},{"type":"function","title":"PairingHeap.size/1","doc":"Return the size of the heap, the total number of nodes.","ref":"PairingHeap.html#size/1"},{"type":"function","title":"Examples - PairingHeap.size/1","doc":"iex> PairingHeap.new(:min, [{1, :a}]) |> PairingHeap.size()\n    1","ref":"PairingHeap.html#size/1-examples"},{"type":"type","title":"PairingHeap.key/0","doc":"","ref":"PairingHeap.html#t:key/0"},{"type":"type","title":"PairingHeap.mode/0","doc":"","ref":"PairingHeap.html#t:mode/0"},{"type":"type","title":"PairingHeap.pair/0","doc":"","ref":"PairingHeap.html#t:pair/0"},{"type":"type","title":"PairingHeap.t/0","doc":"","ref":"PairingHeap.html#t:t/0"},{"type":"type","title":"PairingHeap.value/0","doc":"","ref":"PairingHeap.html#t:value/0"},{"type":"module","title":"PairingHeap.Node","doc":"Defines the `PairingHeap.Node` struct and functions for creating and\ncombining nodes.\n\nThe functions `PairingHeap.Node.merge/3` and `ParingHeap.Node.merge/2`\ncombine pairs and lists of nodes, respectively, in a way that preserves the\nheap property. Both of these functions take as an argument the predicate\n`ordered?/2`, where `ordered?.(node1, node2)` returns `true` if `node1`\nis correctly ordered relatively to `node2` according to the heap property.","ref":"PairingHeap.Node.html"},{"type":"function","title":"PairingHeap.Node.dump/1","doc":"Return a list of all items in the tree defined by the given node.","ref":"PairingHeap.Node.html#dump/1"},{"type":"function","title":"PairingHeap.Node.member?/3","doc":"Return `true` if any node in the tree defined by `node` contains `item`, and\n`false` otherwise.","ref":"PairingHeap.Node.html#member?/3"},{"type":"function","title":"PairingHeap.Node.merge/2","doc":"Merge a list of nodes into a single node that satisfies the heap property.\n\nThe pairwise recursive merger follows the algorithm described in the\n[original paper](https://www.cs.cmu.edu/~sleator/papers/pairing-heaps.pdf),\nwhich has `O(log n)` amortized run time.","ref":"PairingHeap.Node.html#merge/2"},{"type":"function","title":"PairingHeap.Node.merge/3","doc":"Link a pair of nodes into a single node that satisfies the heap property.\n\nOne of the given nodes is a parent and the other is the child, as determined\nby `ordered?/2`. The child node is prepended to the list of child nodes for\nthe parent. No other maintenance is required for the individual nodes in a\npairing heap. It follows that `meld` runs in `O(1)` time.","ref":"PairingHeap.Node.html#merge/3"},{"type":"function","title":"PairingHeap.Node.new/2","doc":"Create a new pairing-heap node with an item and a list of zero or more child\nnodes.","ref":"PairingHeap.Node.html#new/2"},{"type":"type","title":"PairingHeap.Node.item/0","doc":"","ref":"PairingHeap.Node.html#t:item/0"},{"type":"type","title":"PairingHeap.Node.ordered_fn/0","doc":"","ref":"PairingHeap.Node.html#t:ordered_fn/0"},{"type":"type","title":"PairingHeap.Node.t/0","doc":"","ref":"PairingHeap.Node.html#t:t/0"},{"type":"extras","title":"README","doc":"[![Hex.pm Version](https://img.shields.io/hexpm/v/pairing_heap.svg)](https://hex.pm/packages/pairing_heap)\n\n<!-- END HEADER -->\n\nElixir implementation of a\n[_pairing heap_](https://en.wikipedia.org/wiki/Pairing_heap).","ref":"readme.html"},{"type":"extras","title":"Background - README","doc":"A heap is a tree data structure that ensures that the root always has the \nminimum or maximum key value, depending on the desired sort order. The heap was \nfirst introduced in the context of efficient sorting \n(see [_heapsort_](https://en.wikipedia.org/wiki/Heapsort)), but it can also be \nused to implement a \n[priority queue](https://en.wikipedia.org/wiki/Priority_queue).  \n\nEach node of a heap has a _key_ on which the data is ordered, as well as a\ncollection of child nodes. Every heap node satisfies the _heap property_\nthat the node key is either less than or equal to \n(a _min-heap_) or greater than or equal to (a _max-heap_) the keys of its\nchildren. In a min-heap, the root node has the smallest key in the tree, while \nfor a max-heap, the root key is the largest.\n\nA pairing heap is one of a handful of commonly-used heap data structures. It\nhas excellent performance characteristics, with `O(1)` time complexity for an\ninsert and for viewing the root node, and `O(log n)` amortized time complexity \nfor removing the root node and rebuilding the heap. The algorithms for \nmaintaining a pairing heap have especially simple implementations in a\nfunctional language, which is one reason for doing this in Elixir.","ref":"readme.html#background"},{"type":"extras","title":"Usage - README","doc":"`PairingHeap` provides operations for the creation of a heap, for insertion, \nretrieval, and deletion of elements, and for merging multiple heaps.\n\nTo create an empty min-heap that compares keys with `&<=/2`, use \n`PairingHeap.new/1`:\n\n```elixir\niex> PairingHeap.new(:min)\n#PairingHeap \n```\n\nAn empty heap is indicated with `root: :empty`.\n\n> The `PairingHeap` struct is not intended to be used directly. Use the \n> public API when working with an instance of `PairingHeap`.\n\nThe data contained in each node of a heap is a key-value pair expressed as the \ntuple `{key, value}`. A `key` is what is being ordered in the heap, while the \n`value` can be data of any type. Note that a heap is a not a set; duplicate \nkeys, values, and key-value pairs can be present.\n\nMultiple key-value pairs can be added to a heap at the time of creation with \n`PairingHeap.new/2`:\n\n```elixir\niex> PairingHeap.new(:min, [{2, :b}, {1, :a}])\n#PairingHeap \n```\n\nThe first argument to `PairingHeap.new/1` and `PairingHeap.new/2` is the `mode`\nof the heap, which can be one of\n\n  * `:min` - a min-heap, where keys are compared with `&<=/2`\n  * `:max` - a max-heap, where keys are compared with `&>=/2`\n  * `{:min | :max, module}` - a min- or max-heap, where the `module` must\n      implement a `compare` function with signature `(any, any -> :lt | :eq | :gt)`\n\nFor example, a min-heap with `Date` keys would be initialized as\n\n```elixir\niex> PairingHeap.new({:min, Date}, [{~D[2023-09-01], :b}, {~D[2023-08-01], :a}])\n#PairingHeap \n```\n\nTo add a single key-value pair to a heap, use `PairingHeap.put/3`:\n\n```eliixr\niex> PairingHeap.new(:min) |> PairingHeap.put(1, :a)\n#PairingHeap \n```\n\n`PairingHeap.peek/1` is used to obtained the key-value pair of the root without\nmodifying the heap:\n\n```elixir\niex> PairingHeap.new(:min, [{1, :a}]) |> PairingHeap.peek()\n{:ok, {1, :a}}\n```\n\nExtraction and removal of the root node is accomplished with `PairingHeap.pop/1`:\n\n```elixir\niex> {:ok, {key, value}, heap} = \n...>   PairingHeap.new(:min, [{1, :a}]) \n...>   |> PairingHeap.pop()\niex> {key, value}\n{1, :a}\niex> heap\n#PairingHeap \n```\n\nBoth `PairingHeap.peek/1` and `PairingHeap.pop/1` return `:error` if the\nheap is empty.\n\n`PairingHeap.pull/2` pops zero or more key-value pairs from the heap and returns \nthe updated heap:\n\n```elixir\niex> {pairs, heap} =\n...>   PairingHeap.new(:min, [{3, :c}, {1, :a}, {2, :b}])\n...>   |> PairingHeap.pull(2)\niex> pairs\n[{1, :a}, {2, :b}]\niex> heap\n#PairingHeap \n```\n\nIf the number in `PairingHeap.pull/2` is greater than the heap size, all of the \nkey-value pairs are returned, along with an empty heap.\n\nTwo heaps with the same `mode` can be merged with `PairingHeap.merge/2`:\n\n```elixir\niex> heap1 = PairingHeap.new(:min, [{2, :b}])\niex> heap2 = PairingHeap.new(:min, [{1, :a}])\niex> PairingHeap.merge(heap1, heap2)\n#PairingHeap \n```\n\nSimilarly, one or more heaps can be merged with `PairingHeap.merge/1`, which \ntakes a list of heaps as its sole argument:\n\n```elixir\niex> heap1 = PairingHeap.new(:min, [{2, :b}])\niex> heap2 = PairingHeap.new(:min, [{1, :a}])\niex> PairingHeap.merge([heap1, heap2])\n#PairingHeap \n```\n\nTo quickly dump the key-values pairs in the heap without guarantees on the\nordering, use `PairingHeap.dump/1`:\n\n```elixir\niex> h = PairingHeap.new(:min, [{2, :b}, {1, :a}, {3, :c}])\niex> PairingHeap.dump(h)\n[{1, :a}, {3, :c}, {2, :b}]\n```\n\nThis is faster than `Enum.to_list/1` (see below).","ref":"readme.html#usage"},{"type":"extras","title":"Enumerable and Collectable - README","doc":"`PairingHeap` implements the `Enumerable` and `Collectable` protocols, meaning\nthat functions from `Enum` and `Stream` are available. \n\n`Enum.into` is a simple way to add a batch of key-value pairs to a heap:\n\n```elixir\niex> heap = PairingHeap.new(:min, [{2, :b}])\niex> [{3, :c}, {1, :a}] |> Enum.into(heap)\n#PairingHeap \n```\n\nUse `Enum.to_list` to list the entire contents of the heap in key order:\n\n```elixir\niex> heap = PairingHeap.new(:min, [{3, :c}, {1, :a}, {2, :b}])\niex> heap |> Enum.to_list()\n[{1, :a}, {2, :b}, {3, :c}]\n```\n\n`map`, `filter`, and `reduce` are also available for `PairingHeap`. But beware:  \n\n> Any operation that pops `k` elements from a heap will have `O(k log n)`\n> complexity on average.","ref":"readme.html#enumerable-and-collectable"},{"type":"extras","title":"Miscellaneous details - README","doc":"- Like most other heap algorithms, a pairing heap does not produce a \n[stable sort](https://en.wikipedia.org/wiki/Sorting_algorithm#Stability). \n\n- In this implementation of a pairing heap, a new item whose key equals the key\n  of the root node will become the new root node.\n\n```elixir\niex> heap = PairingHeap.new(:min, [{2, :b}, {1, :a}])\niex> heap |> PairingHeap.put(1, :aa) |> Enum.to_list()\n[{1, :aa}, {1, :a}, {2, :b}]\n```\n\n- Emptying a `PairingHeap` with 1,000,000 randomly inserted items takes a \n  couple seconds. For `PairingHeap` sizes less than 1,000,000 the time to \n  pop an item is of order 1 microsecond.","ref":"readme.html#miscellaneous-details"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}